chlorine.reader


binding-form?clj

(binding-form? form)

binding-special?clj

(binding-special? form)

destructuring-form?clj

(destructuring-form? form)

infix-operator?clj

(infix-operator? op)

reserved-symbol?clj

(reserved-symbol? v s)

Checks if a string is specified in reserved symbol list.

Checks if a string is specified in reserved symbol list.
raw docstring

sexp-readerclj

(sexp-reader source)

Wrap source' in a reader suitable to pass toread'.

Wrap `source' in a reader suitable to pass to `read'.
raw docstring

unary-operator?clj

(unary-operator? op)

cljdoc builds & hosts documentation for Clojure/Script libraries