(binding-form? form)(binding-special? form)(destructuring-form? form)(infix-operator? op)(reserved-symbol? v s)Checks if a string is specified in reserved symbol list.
Checks if a string is specified in reserved symbol list.
(sexp-reader source)Wrap source' in a reader suitable to pass toread'.
Wrap `source' in a reader suitable to pass to `read'.
(unary-operator? op)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |